<?php
/**
 * AccountMst Entity
 * $Id: AccountMst.inc,v 1.1 2020/2/22 11:26:51 Exp $
 * @author zb
 * @package jp.compass.entity
 * @access public
 */
class AccountMst extends CompassDynamicData
{
	var $login;
	var $password;
	var $name;
	var $contact;
	var $role;
	var $user_id;
	var $school_id;
	var $government_id;
	var $modules;
	var $comment;
	var $delete_flg;

	/**
	 * 构造实现。account_mst创建实例。
	 * 
	 * @access public
	 * @param mixed account_mst
	 */
	function constructor($record)
	{
		parent::constructor($record);

		$this->login         = $record["login"];
		$this->password      = $record["password"];
		$this->name          = $record["name"];
		$this->contact       = $record["contact"];
		$this->role          = $record["role"];
		$this->user_id       = $record["user_id"];
		$this->school_id     = $record["school_id"];
		$this->government_id = $record["government_id"];
		$this->modules       = $record["modules"];
		$this->comment       = $record["comment"];
		$this->delete_flg    = $record["delete_flg"];
	}

	/**
	 * 根据条件,获取数据列表。
	 * 条件与DBManager的doSelect相同。
	 * @access public
	 * @static
	 * @param array 检索条件
	 * @return array Entity的队列
	 */
	public static function getList($w_param = null, $orderkey = null, $direction = "ASC", $offset = null, $limit = null)
	{
		if ($w_param == null) {
			$w_param = array();
			$w_param["delete_flg"] = "false";
		}

		return CompassDBHandler::getList("AccountMst", "account_mst", $w_param, $orderkey, $direction, $offset, $limit);
	}

	/**
	 * 根据条件，获取数据列表的件数。
	 * 条件与DBManager的doSelect相同。
	 * @access public
	 * @static
	 * @param array 检索条件
	 * @return array Entity的队列
	 */
	public static function getListCount($w_param = null)
	{
		if ($w_param == null) {
			$w_param = array();
			$w_param["delete_flg"] = "false";
		}
		$db = CompassDBManager::getInstance();
		$result = $db->doSelect("account_mst", $w_param, null, null, null, null, "count(*) as count");

		return $result[0]["count"];
	}

	/**
	 * 获得此类指定ID的实例。
	 */
	public static function getById($id)
	{
		// delete_flg
		$param = array();
		$param["delete_flg"] = false;

		return CompassDBHandler::getById("AccountMst", "account_mst", $id, $param);
	}

	// -- 这里开始Dynamic ---
	/**
	 * 将此实例写入DB。
	 * DynamicData共用的保存方法。
	 * @access public
	 * @return int 写入实例的ID
	 */
	public function save()
	{
		$v_param = array();

		ParamUtil::copyObj2Array($v_param, $this, "login");
		ParamUtil::copyObj2Array($v_param, $this, "password");
		ParamUtil::copyObj2Array($v_param, $this, "name");
		ParamUtil::copyObj2ArrayNullField($v_param, $this, "contact");
		ParamUtil::copyObj2Array($v_param, $this, "role");
		ParamUtil::copyObj2Array($v_param, $this, "user_id");
		ParamUtil::copyObj2Array($v_param, $this, "school_id");
		ParamUtil::copyObj2Array($v_param, $this, "government_id");
		ParamUtil::copyObj2Array($v_param, $this, "modules");
		ParamUtil::copyObj2ArrayNullField($v_param, $this, "comment");
		ParamUtil::copyObj2Array($v_param, $this, "delete_flg");

		// 保存
		parent::_save("account_mst", $v_param);
	}
}